part of navigine_api;

class Location {
  int id = 0, sort = 0, userRoleId = 0, userPermissionId = 0;
  String title;
  String description = "";
  bool isPublic = false, activeDragDrop = false, state = false;
  List<SubLocation> subLocations;

  static Location fromMap(var data) {
    return Location()
      ..id = data["id"]
      ..sort = data["sort"]
      // ..state = data["state"]
      ..userRoleId = data["userRoleId"]
      ..userPermissionId = data["userPermissionId"]
      ..title = data["title"]
      ..description = data["description"]
      ..isPublic = data["is_public"]
      ..activeDragDrop = data["active_drag_drop"]
      ..subLocations = (data["subLocations"] ?? [])
          .map<SubLocation>((l) => SubLocation.fromMap(l))
          .toList();
  }

  SubLocation getSubLocationDetail(int id) {
    return subLocations.firstWhere((sl) => sl.id == id);
  }

  /// Returns version of the updated map archive
  Future<int> saveLocation() async {
    var resp = await _httpHelper.postRequest("versions/save", requestParams: {
      "format": "json",
      "locationId": id.toString(),
    });

    return resp["data"]["version"]["version"];
  }

  Future addNewSubLocation(
    String title,
    File image, {
    @required int fileHeight,
    @required int fileWidth,
    @required double lat,
    @required double lon,
    @required int hor,
    @required String timeZone,
  }) async {
    var starting = "data:image/png;base64,";
    var data = await _httpHelper.multipartRequest(
      "sublocations/add",
      body: {
        "title": title,
        "filewidth": fileWidth.toString(),
        "fileheight": fileHeight.toString(),
        "file": starting + base64Encode(image.readAsBytesSync()),
        "lat": lat.toString(),
        "lon": lon.toString(),
        "hor": hor.toString(),
        "timezone": timeZone,
        "navigation_config_id": 1.toString(),
      },
      requestParams: {
        "locationId": id.toString(),
      },
    );

    return SubLocation.fromMap(data);
  }
}
